Attribute VB_Name = "Common"
' --- GPL ---
'
' Copyright (C) 2000-2001 SAP AG
'
' This program is free software; you can redistribute it and/or
' modify it under the terms of the GNU General Public License
' as published by the Free Software Foundation; either version 2
' of the License, or (at your option) any later version.
'
' This program is distributed in the hope that it will be useful,
' but WITHOUT ANY WARRANTY; without even the implied warranty of
' MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
' GNU General Public License for more details.
'
' You should have received a copy of the GNU General Public License
' along with this program; if not, write to the Free Software
' Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
'
' --- GPL ---
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'
' Module: Common.bas
'
'-----------------------------------------------------------------------
'
' responsible:  WolfgangA
'
' special area: SQL Studio Controls
'
' description:  module for global varibles, functions ...
'
'
''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

Option Explicit

'--------------------------------------------------------
' Module Name
'--------------------------------------------------------
Const MODULE_NAME = "common"

Public m_oFSO                  As New FileSystemObject

Public Const WINDOWPLACEMENT = "WindowPlacement"

'=global public variables======================================================
'global object for common functions
Public m_oComFunc As New SQLStudioUtil.Functions
'================================================================================

'=========================================================================================
'    function:      internalError
'    description:   shows message box with error
'    arguments:     [in] CurrentError, vb error object
'                   [in] Modulname, name of source modul
'                   [in] FunctionName, name of used function
'    return value:  /
'
'=========================================================================================
Public Function internalError(ByVal CurrentError As ErrObject, ModulName As String, FunctionName As String)
    MsgBox "Module:" + Chr$(9) + ModulName + Chr$(13) + Chr$(10) + "Function:" + Chr$(9) + FunctionName + Chr$(13) + Chr$(10) + "Error No:" + Chr$(9) + Trim$(Str$(CurrentError.Number)) + Chr$(13) + Chr$(10) + "Error:" + Chr$(9) + CurrentError.Description, vbExclamation, "Unexpected Error:"
End Function

'=========================================================================================
'    function:      spreadHitTest
'    description:   determines which column or row was clicked in a msflexgrid
'    arguments:     [out] nCol, to determined
'                   [out] lRow, to determined
'                   [in] oSpread, msflexgrid to be worked on
'                   [in] x, x value of click
'                   [in] y, y value of click
'    return value:  /
'
'=========================================================================================
Public Function spreadHitTest(nCol As Long, _
                         lRow As Long, _
                         oSpread As MSFlexGrid, _
                         ByVal X As Single, _
                         ByVal Y As Single)
    On Error GoTo errSpreadHitTest

    Const FUNCTION_NAME = "spreadHitTest"
    
    '===============================================================================
    Dim lRun         As Long
    Dim bColFound    As Boolean
    Dim bRowFound    As Boolean
    Dim CurrentCol   As Long
    Dim CurrentRow   As Long
    '===============================================================================
    
    'inits
    nCol = 0
    lRow = 0
    bColFound = False
    bRowFound = False
    CurrentCol = oSpread.Col
    CurrentRow = oSpread.row
    
    'which column is selected?
    For lRun = oSpread.LeftCol To oSpread.Cols - 1
        
        If oSpread.ColPos(lRun) > X Then
            'Get column
            nCol = lRun - 1
            bColFound = True
            Exit For
        End If
    Next
        
    'column found?
    If Not bColFound Then nCol = oSpread.Cols - 1 ' Get last column
    
    'which row is selected?
    For lRun = oSpread.TopRow To oSpread.Rows - 1 ' Get last row
        
        If oSpread.RowPos(lRun) > Y Then
            'Get row
            lRow = lRun - 1
            bRowFound = True
            Exit For
        End If
    Next
        
    'row found?
    If Not bRowFound Then lRow = oSpread.Rows - 1 ' Get last lRow
    
    Exit Function
    
errSpreadHitTest:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      resetRowHeight
'    description:   resets the height of a specific row
'    arguments:     [in] oSpread, msflexgrid to be worked on
'                   [in] lRowNumber, row to be set
'
'    return value:  /
'
'=========================================================================================
Public Function resetRowHeight(oSpread As MSFlexGrid, lRowNumber As Long)
    On Error GoTo errResetRowHeight
    
    Const FUNCTION_NAME = "resetRowHeight"
    
    '=variables===============================================================
    Dim lRun             As Long
    '=========================================================================
    
    'You can set RowHeight to zero to create invisible rows,
    'or to 1 to reset the row height to its default value.
    'The default row height varies according to the current font size.
    For lRun = 1 To lRowNumber
    
        oSpread.rowHeight(lRun) = -1
    Next
    
    Exit Function
    
errResetRowHeight:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      resetRowHeight
'    description:   set a optimal width for columns
'    arguments:     [in] oSpread, msflexgrid to be worked on
'                   [in] lStartRow, rowto start
'
'    return value:  /
'
'=========================================================================================
Public Function bestColumnWidth(oSpread As MSFlexGrid, _
                           lStartRow As Long, _
                           nColStart As Long, _
                           nColSize As Long)
    On Error GoTo errBestColumnWidth
    
    Const FUNCTION_NAME = "bestColumnWidth"
    
    '=variables===============================================================
    Dim lRun               As Long
    '=========================================================================
    
    For lRun = nColStart To nColSize
    
        bestOneColumnWidth oSpread, lStartRow, oSpread.Rows - 1, lRun, qpMaxCharsInColumn, False
    Next
    
    Exit Function
    
errBestColumnWidth:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      bestOneColumnWidth
'    description:   set a optimal width for a column
'    arguments:     [in] oSpread, msflexgrid to be worked on
'                   [in] lStartRow, row to start
'                   [in] lEndRow, row to end
'                   [in] nColNumber, col to be resized
'                   [in] lLimitofCharsInColumn, who many chars in column are considered
'
'    return value:  /
'
'=========================================================================================
Public Function bestOneColumnWidth(oSpread As MSFlexGrid, _
                                   lStartRow As Long, _
                                   lEndRow As Long, _
                                   nColNumber As Long, _
                                   lLimitofCharsInColumn As Long, _
                                   bForceWidth As Boolean)
    On Error GoTo errBestOneColumnWidth
    
    Const FUNCTION_NAME = "bestOneColumnWidth"
    
    '=variables===============================================================
    Dim j                As Long
    Dim CurrentColWidth  As Long
    Dim lMaxColWidth     As Long
    Dim lStrlenTest      As Long
    Dim lTextLength      As Long
    Dim lRowNumbers      As Long
    Dim lAdditionalRow   As Long
    
    Dim lWidthOfOneChar  As Long
    Dim lHeightOfOneChar As Long
    '=========================================================================
    
    'init
    lAdditionalRow = 0
    
    lMaxColWidth = oSpread.ColWidth(nColNumber)
    'if colwidth is 0 don't determine best width
    'except bForceWidth is true or it's the zero (row count) column
    If lMaxColWidth = 0 And Not bForceWidth And nColNumber <> 0 Then
    
        Exit Function
    Else
      lMaxColWidth = 10
    End If
    
    'TextHeight is needed, so abuse frmZoomn
    frmZoom.Font.Size = oSpread.CellFontSize
    
    'get a avarage width of a char
    lWidthOfOneChar = frmZoom.TextWidth(" !abcdefghiABCDEFGHI1234567890") \ 30
    
    'get height of a char
    lHeightOfOneChar = 10 * frmZoom.TextHeight("W") \ 9
        
    'set valid start row
    If lStartRow < 0 Then lStartRow = 0
                                     
    For j = lStartRow To lEndRow Step 1
    
        'j = 0 because of header row, j-1 for the first result row
        'Mod 9 to format the first 2 digit number (10 row)
        'for performance just take every 10th Row or just one line
        If j = 0 Or (j - 1) Mod 9 = 0 Or lStartRow = lEndRow Then
        
            lStrlenTest = Len(oSpread.TextMatrix(j, nColNumber))
            'make width a least for 2 chars
            If lStrlenTest < 2 Then lStrlenTest = 2
            
            lTextLength = 21 * lWidthOfOneChar * lStrlenTest / 10
            'dont use Limit for negative Value e.g. -1
            If lLimitofCharsInColumn > 0 Then
               
                If lStrlenTest < lLimitofCharsInColumn Then
                
                    CurrentColWidth = lTextLength
                Else
                    CurrentColWidth = lWidthOfOneChar * (lLimitofCharsInColumn + 5)
                End If
            Else
                CurrentColWidth = lTextLength
            End If
                            
            If CurrentColWidth > oSpread.Width Then
            
                lAdditionalRow = 0
                CurrentColWidth = (2 * oSpread.Width) / 3
            Else
                lAdditionalRow = 1
            End If
            
            If CurrentColWidth > lMaxColWidth Then
            
                lMaxColWidth = CurrentColWidth
                 'don't use Limit for negative Value e.g. -1
                If lLimitofCharsInColumn > 0 Then
                
                    If lMaxColWidth > lWidthOfOneChar * lLimitofCharsInColumn _
                       Then lMaxColWidth = lWidthOfOneChar * lLimitofCharsInColumn
               End If
            End If
        End If
        
        lRowNumbers = m_oComFunc.Max(2, lAdditionalRow + lTextLength \ lMaxColWidth)
        
        If lLimitofCharsInColumn > 0 Then

            oSpread.rowHeight(j) = -1
        Else
            oSpread.rowHeight(j) = lHeightOfOneChar * lRowNumbers
        End If
    Next
        
    oSpread.ColWidth(nColNumber) = lMaxColWidth
    
    Exit Function
    
errBestOneColumnWidth:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      setSpreadFont
'    description:   set from with values from GlobalInfo.userprofile
'    arguments:     [in] oGlobal, pointer to global com object
'                   [in] oSpread, msflexgrid to be worked on
'
'    return value:  /
'
'=========================================================================================
Public Function setSpreadFont(oGlobal As globalInfo, oSpread As MSFlexGrid)
    On Error GoTo errSetSpreadFont
    
    Const FUNCTION_NAME = "setSpreadFont"
    
    '=variables===============================================================
    Dim Name                As String
    Dim FontBold            As Boolean
    Dim FontItalic          As Boolean
    Dim FontSize            As Long
    Dim FontStrikethrough   As Boolean
    Dim FontUnderline       As Boolean
    
    Dim lLastRow        As Long
    Dim lLastRows       As Long
    Dim lLastCols       As Long
    Dim lLastCol        As Long
    '=========================================================================
    
    oGlobal.UserProfile.GetReportFont Name, _
                                        FontBold, _
                                        FontItalic, _
                                        FontSize, _
                                        FontStrikethrough, _
                                        FontUnderline
    
    lLastRow = oSpread.row
    lLastRows = oSpread.RowSel
    lLastCol = oSpread.Col
    lLastCols = oSpread.ColSel
    
    oSpread.row = 0
    oSpread.Col = 0
    
    oSpread.RowSel = oSpread.Rows - 1
    oSpread.ColSel = oSpread.Cols - 1
    
    oSpread.CellFontBold = FontBold
    oSpread.CellFontSize = FontSize
    oSpread.CellFontName = Name
    oSpread.CellFontItalic = FontItalic
    oSpread.CellFontStrikeThrough = FontStrikethrough
    oSpread.CellFontUnderline = FontUnderline
    
    oSpread.row = lLastRow
    oSpread.Col = lLastCol
    oSpread.RowSel = lLastRows
    oSpread.ColSel = lLastCols
    
    Exit Function

errSetSpreadFont:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

'=========================================================================================
'    function:      getColumnType
'    description:   returns the clumntype identified with a string
'    arguments:     [in] sDBColumn, columntype as string
'
'    return value:  SAPDBColumnType
'
'=========================================================================================
Public Function getColumnType(ByVal sDBColumn As String) As SAPDBColumnType
    On Error GoTo errGetColumnType

    Const FUNCTION_NAME = "getColumnType"
        
    getColumnType = sapdbColTypeUnknown
    
    'select column type
    Select Case sDBColumn
        Case "CHAR":
            getColumnType = sapdbColTypeChar
        Case "VARCHAR":
            getColumnType = sapdbColTypeVarChar
        Case "LONG":
            getColumnType = sapdbColTypeLong
        Case "BOOLEAN":
            getColumnType = sapdbColTypeBoolean
        Case "FIXED":
            getColumnType = sapdbColTypeFixed
        Case "FLOAT":
            getColumnType = sapdbColTypeFloat
        Case "INT", "INTEGER":
            getColumnType = sapdbColTypeInt
        Case "SMALLINT", "SMALLINTEGER":
            getColumnType = sapdbColTypeSmallInt
        Case "DATE":
            getColumnType = sapdbColTypeDate
        Case "TIME":
            getColumnType = sapdbColTypeTime
        Case "TIMESTAMP":
            getColumnType = sapdbColTypeTimeStamp
        Case Else
            getColumnType = sapdbColTypeUnknown
    End Select
    
    Exit Function
    
errGetColumnType:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      getColumnType
'    description:   returns the name and owner of a synonym
'    arguments:     [in] sTableOwner, owner of synonym table
'                   [in] sTableName, name of synonym table
'                   [out] sOrgOwner, original owner of synonym table
'                   [out] sOrgName,original name of synonym table
'
'    return value:  true if success
'
'=========================================================================================
Public Function getSynonym(oConnection As SQLStudioDBLayer.connection, _
                            ByVal sTableOwner As String, _
                            ByVal sTableName As String, _
                            sOrgOwner As String, _
                            sOrgname As String) As Boolean
    On Error GoTo errGetSynonym

    Const FUNCTION_NAME = "GetSynonym"

    '=variables===============================================================
    Dim sStatement              As String
    Dim oResult                 As New SQLStudioDBLayer.result
    '=========================================================================
    
    'rc
    getSynonym = False

    'inits
    sOrgOwner = ""
    sOrgname = ""

    sStatement = "SELECT TABLEOWNER ,TABLENAME FROM DOMAIN.SYNONYMS WHERE OWNER" + _
                 " = '" + m_oComFunc.convertStringForCharCol(sTableOwner, True) + "' AND " + _
                 "SYNONYMNAME  = '" + m_oComFunc.convertStringForCharCol(sTableName, True) + "'"
    
    Set oResult.connection = oConnection
    If Not oResult.OpenResult(sStatement, Internal) Then Exit Function
    
    'get next row
    If Not oResult.Fetch Then Exit Function
    
    If oResult.NoRows Then
        
        sOrgOwner = sTableOwner
        sOrgname = sTableName
        'rc
        getSynonym = True
        Exit Function
    End If
    
    'Get data
    If oResult.GetData() = False Then Exit Function
     
    sOrgOwner = oResult.Columns(1).ColValue
    sOrgname = oResult.Columns(2).ColValue
    
    'rc
    getSynonym = True

    Exit Function

errGetSynonym:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      isSynonympPublic
'    description:   check if a sysnonym is public
'    arguments:     [in] sTableOwner, owner of synonym table
'                   [in] sTableName, name of synonym table'
'
'    return value:  true if success
'
'=========================================================================================
Public Function isSynonympPublic(oConnection As SQLStudioDBLayer.connection, _
                                 ByVal tableOwner As String, _
                                 ByVal tableName As String) As Boolean
    On Error GoTo errIsSynonympPublic

    Const FUNCTION_NAME = "isSynonympPublic"

    '=variables===============================================================
    Dim sStatement            As String
    Dim oResult               As New SQLStudioDBLayer.result
    '=========================================================================
    
    'rc
    isSynonympPublic = False
    
    Set oResult.connection = oConnection
    
    sStatement = "SELECT PUBLIC FROM DOMAIN.SYNONYMS WHERE OWNER  = '" + _
                 m_oComFunc.convertStringForCharCol(tableOwner, True) + "' AND SYNONYMNAME = '" + m_oComFunc.convertStringForCharCol(tableName, True) + "'"
    
    If Not oResult.OpenResult(sStatement, Internal) Then Exit Function
    
    'get next row
    If Not oResult.Fetch Then Exit Function
       
    'Get data
    If Not oResult.NoRows Then
    
        oResult.LimitForLong = -1
        If oResult.GetData() Then
        
            If oResult.Columns(1).ColValue = "YES" Then isSynonympPublic = True
        End If
     End If
    
    Set oResult = Nothing
    
    Exit Function

errIsSynonympPublic:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      drawResultLine
'    description:   draw the result of a databse result into grid
'    arguments:     /
'
'    return value:  /
'
'=========================================================================================
Public Function drawResultLine(lRow As Long, grdResult As MSFlexGrid, oResult As SQLStudioDBLayer.result, bReplaceNC As Boolean)
    On Error GoTo errDrawResultLine

    Const FUNCTION_NAME = "drawResultLine"

    '=local variables===================
    Dim nCol            As Integer
    Dim sRepresentData  As String
    '===================================
    
    For nCol = 1 To oResult.colCount
            
        If lRow <> grdResult.row Then grdResult.row = lRow
        If nCol <> grdResult.Col Then grdResult.Col = nCol
        
        If Not oResult.getColumnData(nCol) Then
        
            oResult.showError
        Else
            If bReplaceNC And _
                (oResult.Columns.item(nCol).odbcColType = odbcColTypeBinary Or _
                oResult.Columns.item(nCol).odbcColType = odbcColTypeVarBinary Or _
                oResult.Columns.item(nCol).odbcColType = odbcColTypeLongVarChar Or _
                oResult.Columns.item(nCol).odbcColType = odbcColTypeLongVarBinary Or _
                oResult.Columns.item(nCol).odbcColType = odbcColTypeWLongVarChar) _
            Then
               sRepresentData = oResult.Columns.item(nCol).ColValue
               m_oComFunc.replaceNonChars sRepresentData
               grdResult.text = sRepresentData
            Else
               grdResult.text = oResult.Columns(nCol).ColValue
            End If
        End If
    Next
    
    Exit Function
    
errDrawResultLine:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
'=========================================================================================
'    function:      tableExists
'    description:   check if a table exists in the database
'    arguments:     [in] sTableName, name of table
'
'    return value:  true if success
'
'=========================================================================================
Public Function tableExists(oConnection As SQLStudioDBLayer.connection, _
                            ByVal tableName As String) As Boolean
    On Error GoTo errTableExists

    Const FUNCTION_NAME = "tableExists"

    '=variables===============================================================
    Dim sStatement            As String
    Dim oResult               As New SQLStudioDBLayer.result
    '=========================================================================
    
    'rc
    tableExists = False
    
    Set oResult.connection = oConnection
    
    sStatement = "SELECT TABLENAME FROM DOMAIN.TABLES WHERE TABLENAME  = '" + m_oComFunc.convertStringForCharCol(tableName, True) + "'" + " AND TYPE <> 'SYNONYM'"
    If Not oResult.OpenResult(sStatement, Internal) Then Exit Function
    
    'get next row
    If Not oResult.Fetch Then Exit Function
       
    'Get data
    If Not oResult.NoRows Then
    
        oResult.LimitForLong = -1
        If oResult.GetData() Then tableExists = True
     End If
    
    Set oResult = Nothing
    
    Exit Function

errTableExists:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function initAutoCommitListBox(list As ComboBox)
    On Error GoTo errInitAutoCommitListBox

    Const FUNCTION_NAME = "initAutoCommitListBox"

    list.AddItem LoadResString(330)
    list.AddItem LoadResString(331)
    
    Exit Function
    
errInitAutoCommitListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function initSQLModeListBox(list As ComboBox)
    On Error GoTo errInitSQLModeListBox
    
    Const FUNCTION_NAME = "initSQLModeListBox"

    list.AddItem LoadResString(321)
    list.AddItem LoadResString(324)
    list.AddItem LoadResString(322)
    list.AddItem LoadResString(323)
        
    Exit Function
    
errInitSQLModeListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function initIsoLevelListBox(list As ComboBox)
    On Error GoTo errInitIsoLevelListBox
    
    Const FUNCTION_NAME = "initIsoLevelListBox"

    list.AddItem LoadResString(301)
    list.AddItem LoadResString(302)
    list.AddItem LoadResString(303)
    list.AddItem LoadResString(304)
    
    Exit Function
    
errInitIsoLevelListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

Public Function listIndexAutoCommitListBox(list As ComboBox, item As String)
    On Error GoTo errlistIndexAutoCommitListBox

    Const FUNCTION_NAME = "listIndexAutoCommitListBox"

    If LoadResString(330) = item Then
        list.ListIndex = 0
    Else
        list.ListIndex = 1
    End If
    
    Exit Function
    
errlistIndexAutoCommitListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function getAutoCommitListBox(list As ComboBox)
    On Error GoTo errgetAutoCommitListBox

    Const FUNCTION_NAME = "getAutoCommitListBox"

    Dim item As String
    item = list.text

    If LoadResString(330) = item Then
        getAutoCommitListBox = AutoCommitOn
    Else
        getAutoCommitListBox = AutoCommitOff
    End If
    
    Exit Function
    
errgetAutoCommitListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

Public Function getSQLModeFromListBox(list As ComboBox) As sqlMode
    On Error GoTo errgetSQLModeFromListBox
    
    Const FUNCTION_NAME = "getSQLModeFromListBox"
    
    Dim item As String
    item = list.text

    If LoadResString(321) = item Then
        getSQLModeFromListBox = Internal
    ElseIf LoadResString(322) = item Then
        getSQLModeFromListBox = DB2
    ElseIf LoadResString(323) = item Then
        getSQLModeFromListBox = Ansi
    ElseIf LoadResString(324) = item Then
        getSQLModeFromListBox = Oracle
    End If
    
    Exit Function
    
errgetSQLModeFromListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function listIndexSQLModeListBox(list As ComboBox, item As String)
    On Error GoTo errlistIndexSQLModeListBox
    
    Const FUNCTION_NAME = "listIndexSQLModeListBox"

    If LoadResString(321) = item Then
        list.ListIndex = 0
    ElseIf LoadResString(324) = item Then
        list.ListIndex = 1
    ElseIf LoadResString(322) = item Then
        list.ListIndex = 2
    ElseIf LoadResString(323) = item Then
        list.ListIndex = 3
    End If
    
    Exit Function
    
errlistIndexSQLModeListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function
Public Function listIndexIsoLevelListBox(list As ComboBox, item As String)
    On Error GoTo errlistIndexIsoLevelListBox
    
    Const FUNCTION_NAME = "listIndexIsoLevelListBox"

    If LoadResString(301) = item Then
        list.ListIndex = 0
    ElseIf LoadResString(302) = item Then
        list.ListIndex = 1
    ElseIf LoadResString(303) = item Then
        list.ListIndex = 2
    ElseIf LoadResString(304) = item Then
        list.ListIndex = 3
    End If
    
    Exit Function
    
errlistIndexIsoLevelListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function


Public Function getIsoLevelFromListBox(list As ComboBox) As isoLevel
    On Error GoTo errgetIsoLevelFromListBox
    
    Const FUNCTION_NAME = "getIsoLevelFromListBox"

    Dim item As String
    item = list.text
    
    If LoadResString(301) = item Then
        getIsoLevelFromListBox = UnCommitted
    ElseIf LoadResString(302) = item Then
        getIsoLevelFromListBox = Committed
    ElseIf LoadResString(303) = item Then
        getIsoLevelFromListBox = Repeatable
    ElseIf LoadResString(304) = item Then
        getIsoLevelFromListBox = Serializable
    End If
    
    Exit Function
    
errgetIsoLevelFromListBox:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

'=========================================================================================
'    function:      showOpenConnectionError
'    description:   shows the error with the resource id 142
'    arguments:     oConnection: connection object
'
'    return value:  /
'
'=========================================================================================
Function showOpenConnectionError(oConnection As connection)
    On Error GoTo errShowOpenConnectionError
    
    Const FUNCTION_NAME = "showOpenConnectionError"

    '"-23062 Couldn't open connection !"
    MsgBox LoadResString(142) + _
            " (" + _
            oConnection.autoCommitAsString + _
            ", " + _
            oConnection.sqlModeAsString + _
            ", " + _
            oConnection.isoLevelAsString + ")", _
            , vbCritical
    
    Exit Function
    
errShowOpenConnectionError:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

'=========================================================================================
'    function:      openFile
'    description:   open a file
'    arguments:     [in] sFilename
'                   [in] bAppend
'
'    return value:  free file handle
'
'=========================================================================================
Public Function openFile(sFilename As String, bAppend As Boolean) As Integer
    On Error GoTo errOpenFile

    Const FUNCTION_NAME = "openFile"
    
    Dim nFileNumber     As Integer
    
    nFileNumber = FreeFile
    
    'if file already exists delete it
    If (Not bAppend) Then
        If m_oFSO.FileExists(sFilename) Then m_oFSO.DeleteFile sFilename
    End If
    
    Open sFilename For Binary Access Write As nFileNumber
    
    openFile = nFileNumber
    
    Exit Function
    
errOpenFile:
    internalError Err, MODULE_NAME, FUNCTION_NAME
End Function

